package com.ruoyi.ngtools.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.ngtools.domain.NgMeterresult;
import com.ruoyi.ngtools.service.INgMeterresultService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 流量计算结果Controller
 * 
 * @author ruoyi
 * @date 2025-02-09
 */
@RestController
@RequestMapping("/ngtools/meterresult")
public class NgMeterresultController extends BaseController
{
    @Autowired
    private INgMeterresultService ngMeterresultService;

    /**
     * 查询流量计算结果列表
     */
    @PreAuthorize("@ss.hasPermi('ngtools:meterresult:list')")
    @GetMapping("/list")
    public TableDataInfo list(NgMeterresult ngMeterresult)
    {
        startPage();
        List<NgMeterresult> list = ngMeterresultService.selectNgMeterresultList(ngMeterresult);
        return getDataTable(list);
    }

    /**
     * 导出流量计算结果列表
     */
    @PreAuthorize("@ss.hasPermi('ngtools:meterresult:export')")
    @Log(title = "流量计算结果", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, NgMeterresult ngMeterresult)
    {
        List<NgMeterresult> list = ngMeterresultService.selectNgMeterresultList(ngMeterresult);
        ExcelUtil<NgMeterresult> util = new ExcelUtil<NgMeterresult>(NgMeterresult.class);
        util.exportExcel(response, list, "流量计算结果数据");
    }

    /**
     * 获取流量计算结果详细信息
     */
    @PreAuthorize("@ss.hasPermi('ngtools:meterresult:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(ngMeterresultService.selectNgMeterresultById(id));
    }

    /**
     * 新增流量计算结果
     */
    @PreAuthorize("@ss.hasPermi('ngtools:meterresult:add')")
    @Log(title = "流量计算结果", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody NgMeterresult ngMeterresult)
    {
        return toAjax(ngMeterresultService.insertNgMeterresult(ngMeterresult));
    }

    /**
     * 修改流量计算结果
     */
    @PreAuthorize("@ss.hasPermi('ngtools:meterresult:edit')")
    @Log(title = "流量计算结果", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody NgMeterresult ngMeterresult)
    {
        return toAjax(ngMeterresultService.updateNgMeterresult(ngMeterresult));
    }

    /**
     * 删除流量计算结果
     */
    @PreAuthorize("@ss.hasPermi('ngtools:meterresult:remove')")
    @Log(title = "流量计算结果", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(ngMeterresultService.deleteNgMeterresultByIds(ids));
    }
}
